@@ -39,10 +39,20 @@ module Sus
 				instance = self.new(assertions)
 				
 				instance.around do
-					instance.call
+					handle_skip(instance, assertions)
 				end
 			end
 		end
+		
+		def handle_skip(instance, assertions)
+			reason = catch(:skip) do
+				return instance.call
+			end
+			
+			assertions.skip(reason)
+			
+			return nil
+		end
 	end
 	
 	module Context
@@ -50,4 +60,10 @@ module Sus
 			add It.build(self, ...)
 		end
 	end
+	
+	class Base
+		def skip(reason)
+			throw :skip, reason
+		end
+	end
 end
